#ifndef STRUCT_VOID_LIST_H
#define STRUCT_VOID_LIST_H

// 双方向リスト
typedef struct void_list
{
	void *data;
	struct void_list *next;
	struct void_list *prev;
	// tailは先頭の要素のみ使用、他はNULL
	struct void_list *tail;
} VList;

#endif
